@@ -5,20 +5,20 @@ from . import documents, results, html_paths
 from .html_generation import HtmlGenerator, satisfy_html_path
 
 
-def convert_document_element_to_html(element, styles=None, convert_image=None):
-    if styles is None:
-        styles = []
+def convert_document_element_to_html(element, style_map=None, convert_image=None):
+    if style_map is None:
+        style_map = []
     html_generator = HtmlGenerator()
-    converter = DocumentConverter(styles, convert_image=convert_image)
+    converter = DocumentConverter(style_map, convert_image=convert_image)
     converter.convert_element_to_html(element, html_generator,)
     html_generator.end_all()
     return results.Result(html_generator.html_string(), converter.messages)
 
 
 class DocumentConverter(object):
-    def __init__(self, styles, convert_image):
+    def __init__(self, style_map, convert_image):
         self.messages = []
-        self._styles = styles
+        self._style_map = style_map
         self._converters = {
             documents.Document: self._convert_document,
             documents.Paragraph: self._convert_paragraph,
@@ -99,13 +99,16 @@ class DocumentConverter(object):
         
     
     def _find_html_path(self, element, element_type, default):
-        for style in self._styles:
+        for style in self._style_map:
             document_matcher = style.document_matcher
             if _document_matcher_matches(document_matcher, element, element_type):
                 return style.html_path
         
-        if element.style_name is not None:
-            self.messages.append(results.warning("Unrecognised {0} style: {1}".format(element_type, element.style_name)))
+        if element.style_id is not None:
+            self.messages.append(results.warning(
+                "Unrecognised {0} style: {1} (Style ID: {2})".format(
+                    element_type, element.style_name, element.style_id)
+            ))
         
         return default
         
@@ -113,6 +116,9 @@ class DocumentConverter(object):
 def _document_matcher_matches(matcher, element, element_type):
     return (
         matcher.element_type == element_type and (
+            matcher.style_id is None or
+            matcher.style_id == element.style_id
+        ) and (
             matcher.style_name is None or
             matcher.style_name == element.style_name
         ) and (
